@@ -38,6 +38,16 @@ DEFAULT_POLICY_OUTPUT_OUTGOING = """Default outgoing policy changed to 'allow'
 (be sure to update your rules accordingly)
 """
 
+UFW_STATUS_NUMBERED = """Status: active
+
+     To                         Action      From
+     --                         ------      ----
+[ 1] 6641/tcp                   ALLOW IN    10.219.3.86                # charm-ovn-central
+[12] 6641/tcp                   REJECT IN   Anywhere
+[19] 6644/tcp (v6)              REJECT IN   Anywhere (v6)              # charm-ovn-central
+
+"""
+
 
 class TestUFW(unittest.TestCase):
     @mock.patch('charmhelpers.core.hookenv.log')
@@ -217,6 +227,53 @@ class TestUFW(unittest.TestCase):
                              'to 127.0.0.1 port 80'), level='DEBUG')
         log.assert_any_call('stdout', level='INFO')
 
+    @mock.patch('charmhelpers.contrib.network.ufw.is_enabled')
+    @mock.patch('charmhelpers.core.hookenv.log')
+    @mock.patch('subprocess.Popen')
+    def test_modify_access_prepend(self, popen, log, is_enabled):
+        is_enabled.return_value = True
+        p = mock.Mock()
+        p.configure_mock(**{'communicate.return_value': ('stdout', 'stderr'),
+                            'returncode': 0})
+        popen.return_value = p
+        ufw.modify_access('127.0.0.1', dst='127.0.0.1', port='80',
+                          prepend=True)
+        popen.assert_any_call(['ufw', 'prepend', 'allow', 'from', '127.0.0.1',
+                               'to', '127.0.0.1', 'port', '80'],
+                              stdout=subprocess.PIPE)
+        log.assert_any_call(('ufw allow: ufw prepend allow from 127.0.0.1 '
+                             'to 127.0.0.1 port 80'), level='DEBUG')
+        log.assert_any_call('stdout', level='INFO')
+
+    @mock.patch('charmhelpers.contrib.network.ufw.is_enabled')
+    @mock.patch('charmhelpers.core.hookenv.log')
+    @mock.patch('subprocess.Popen')
+    def test_modify_access_comment(self, popen, log, is_enabled):
+        is_enabled.return_value = True
+        p = mock.Mock()
+        p.configure_mock(**{'communicate.return_value': ('stdout', 'stderr'),
+                            'returncode': 0})
+        popen.return_value = p
+        ufw.modify_access('127.0.0.1', dst='127.0.0.1', port='80',
+                          comment='No comment')
+        popen.assert_any_call(['ufw', 'allow', 'from', '127.0.0.1',
+                               'to', '127.0.0.1', 'port', '80',
+                               'comment', 'No comment'],
+                              stdout=subprocess.PIPE)
+
+    @mock.patch('charmhelpers.contrib.network.ufw.is_enabled')
+    @mock.patch('charmhelpers.core.hookenv.log')
+    @mock.patch('subprocess.Popen')
+    def test_modify_access_delete_index(self, popen, log, is_enabled):
+        is_enabled.return_value = True
+        p = mock.Mock()
+        p.configure_mock(**{'communicate.return_value': ('stdout', 'stderr'),
+                            'returncode': 0})
+        popen.return_value = p
+        ufw.modify_access(None, dst=None, action='delete', index=42)
+        popen.assert_any_call(['ufw', '--force', 'delete', '42'],
+                              stdout=subprocess.PIPE)
+
     @mock.patch('charmhelpers.contrib.network.ufw.is_enabled')
     @mock.patch('charmhelpers.core.hookenv.log')
     @mock.patch('subprocess.Popen')
@@ -441,3 +498,53 @@ class TestUFW(unittest.TestCase):
     @mock.patch('subprocess.check_output')
     def test_change_default_policy_wrong_direction(self, check_output, log):
         self.assertRaises(ufw.UFWError, ufw.default_policy, 'allow', 'asdf')
+
+    @mock.patch('charmhelpers.core.hookenv.log')
+    @mock.patch('subprocess.check_output')
+    @mock.patch('charmhelpers.contrib.network.ufw.modprobe')
+    def test_reload_ok(self, modprobe, check_output, log):
+        msg = 'Firewall reloaded\n'
+        check_output.return_value = msg
+        self.assertTrue(ufw.reload())
+
+        check_output.assert_any_call(['ufw', 'reload'],
+                                     universal_newlines=True,
+                                     env={'LANG': 'en_US',
+                                          'PATH': os.environ['PATH']})
+        log.assert_any_call(msg, level='DEBUG')
+        log.assert_any_call('ufw reloaded', level='INFO')
+
+    @mock.patch('charmhelpers.core.hookenv.log')
+    @mock.patch('subprocess.check_output')
+    @mock.patch('charmhelpers.contrib.network.ufw.modprobe')
+    def test_reload_fail(self, modprobe, check_output, log):
+        msg = 'This did not work\n'
+        check_output.return_value = msg
+        self.assertFalse(ufw.reload())
+
+        check_output.assert_any_call(['ufw', 'reload'],
+                                     universal_newlines=True,
+                                     env={'LANG': 'en_US',
+                                          'PATH': os.environ['PATH']})
+        log.assert_any_call(msg, level='DEBUG')
+        log.assert_any_call("ufw couldn't be reloaded", level='WARN')
+
+    def test_status(self):
+        with mock.patch('subprocess.check_output') as check_output:
+            check_output.return_value = UFW_STATUS_NUMBERED
+            expect = {
+                1: {'to': '6641/tcp', 'action': 'allow in',
+                    'from': '10.219.3.86', 'ipv6': False,
+                    'comment': 'charm-ovn-central'},
+                12: {'to': '6641/tcp', 'action': 'reject in',
+                     'from': 'any', 'ipv6': False,
+                     'comment': ''},
+                19: {'to': '6644/tcp', 'action': 'reject in',
+                     'from': 'any', 'ipv6': True,
+                     'comment': 'charm-ovn-central'},
+            }
+            n_rules = 0
+            for n, r in ufw.status():
+                self.assertDictEqual(r, expect[n])
+                n_rules += 1
+            self.assertEquals(n_rules, 3)
