@@ -66,21 +66,26 @@ class ConfigTest(TestCase):
         d = dict(foo='bar')
         c = hookenv.Config(d)
 
-        with open(c.path, 'w') as f:
+        state_path = os.path.join(self.charm_dir, hookenv.Config.CONFIG_FILE_NAME)
+        with open(state_path, 'w') as f:
             f.close()
 
         self.assertEqual(c['foo'], 'bar')
         self.assertEqual(c._prev_dict, None)
+        self.assertEqual(c.path, state_path)
 
     def test_init_invalid_state_file(self):
         d = dict(foo='bar')
-        c = hookenv.Config(d)
 
-        with open(c.path, 'w') as f:
+        state_path = os.path.join(self.charm_dir, hookenv.Config.CONFIG_FILE_NAME)
+        with open(state_path, 'w') as f:
             f.write('blah')
 
+        c = hookenv.Config(d)
+
         self.assertEqual(c['foo'], 'bar')
         self.assertEqual(c._prev_dict, None)
+        self.assertEqual(c.path, state_path)
 
     def test_load_previous(self):
         d = dict(foo='bar')
